=====================================
toll — poor man's integration testing
=====================================

.. image:: https://img.shields.io/pypi/v/toll.svg
        :target: https://pypi.org/project/toll/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/toll.svg
        :target: https://pypi.org/project/toll/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/icemac/toll.svg?branch=master
        :target: https://travis-ci.org/icemac/toll

.. image:: https://readthedocs.org/projects/toll/badge/?version=latest
        :target: https://toll.readthedocs.io/en/latest/
        :alt: Documentation Status

toll = **t**\ est **o**\ ffline **l**\ ocally **l**\ ightweight

Run the tests of multiple configured packages:

* right one package after another

* stopping with the first package which has a failing test

This package is compatible with Python 2.7, 3.5, 3.6, 3.7, PyPy2 and PyPy3.

Documentation see: http://toll.readthedocs.io

This package is licensed under the MIT License, see LICENSE.txt inside the
package.
